@@ -1,6 +1,6 @@
-package Pcore::API::Moz v0.5.0;
+package Pcore::API::Moz v0.6.0;
 
-use Pcore -dist, -class, -status;
+use Pcore -dist, -class, -result;
 use Pcore::Util::Digest qw[hmac_sha1];
 use Pcore::HTTP::CookieJar;
 
@@ -69,19 +69,19 @@ sub url_metrics ( $self, $domains, $metric, $cb ) {
                 my $api_res;
 
                 if ( $res->status != 200 ) {
-                    $api_res = status [ $res->status, $res->reason ];
+                    $api_res = result [ $res->status, $res->reason ];
                 }
                 else {
                     my $json = eval { P->data->from_json( $res->body->$* ); };
 
                     if ($@) {
-                        $api_res = status [ 999, 'Invalid JSON body' ];
+                        $api_res = result [ 999, 'Invalid JSON body' ];
                     }
                     else {
-                        $api_res = status 200;
+                        $api_res = result 200;
 
                         for my $i ( 0 .. $domains->$#* ) {
-                            $api_res->{result}->{ $domains->[$i] } = $json->[$i];
+                            $api_res->{data}->{ $domains->[$i] } = $json->[$i];
                         }
                     }
                 }
